@@ -28,9 +28,20 @@ from . import exc
 from .common import PaneDict, WindowOptionDict, handle_option_error
 
 if t.TYPE_CHECKING:
+    import sys
+    import types
+
+    from libtmux._internal.types import StrPath
+
     from .server import Server
     from .session import Session
 
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -73,6 +84,13 @@ class Window(Obj):
     >>> window in session.windows
     True
 
+    The window can be used as a context manager to ensure proper cleanup:
+
+    >>> with session.new_window() as window:
+    ...     pane = window.split()
+    ...     # Do work with the pane
+    ...     # Window will be killed automatically when exiting the context
+
     References
     ----------
     .. [window_manual] tmux window. openbsd manpage for TMUX(1).
@@ -85,6 +103,39 @@ class Window(Obj):
 
     server: Server
 
+    def __enter__(self) -> Self:
+        """Enter the context, returning self.
+
+        Returns
+        -------
+        :class:`Window`
+            The window instance
+        """
+        return self
+
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: types.TracebackType | None,
+    ) -> None:
+        """Exit the context, killing the window if it exists.
+
+        Parameters
+        ----------
+        exc_type : type[BaseException] | None
+            The type of the exception that was raised
+        exc_value : BaseException | None
+            The instance of the exception that was raised
+        exc_tb : types.TracebackType | None
+            The traceback of the exception that was raised
+        """
+        if (
+            self.window_id is not None
+            and len(self.session.windows.filter(window_id=self.window_id)) > 0
+        ):
+            self.kill()
+
     def refresh(self) -> None:
         """Refresh window attributes from tmux."""
         assert isinstance(self.window_id, str)
@@ -209,7 +260,7 @@ class Window(Obj):
         self,
         /,
         target: int | str | None = None,
-        start_directory: str | None = None,
+        start_directory: StrPath | None = None,
         attach: bool = False,
         direction: PaneDirection | None = None,
         full_window_split: bool | None = None,
@@ -225,7 +276,7 @@ class Window(Obj):
         attach : bool, optional
             make new window the current window after creating it, default
             True.
-        start_directory : str, optional
+        start_directory : str or PathLike, optional
             specifies the working directory in which the new window is created.
         direction : PaneDirection, optional
             split in direction. If none is specified, assume down.
@@ -743,7 +794,7 @@ class Window(Obj):
         """Representation of :class:`Window` object."""
         return (
             f"{self.__class__.__name__}({self.window_id} "
-            + f"{self.window_index}:{self.window_name}, {self.session})"
+            f"{self.window_index}:{self.window_name}, {self.session})"
         )
 
     #
@@ -815,7 +866,7 @@ class Window(Obj):
     def split_window(
         self,
         target: int | str | None = None,
-        start_directory: str | None = None,
+        start_directory: StrPath | None = None,
         attach: bool = False,
         vertical: bool = True,
         shell: str | None = None,
@@ -849,7 +900,7 @@ class Window(Obj):
             # Deprecated in 3.1 in favor of -l
             warnings.warn(
                 f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
-                + ' ("-l" flag) in tmux 3.1+.',
+                ' ("-l" flag) in tmux 3.1+.',
                 category=DeprecationWarning,
                 stacklevel=2,
             )
